Backend -- Setuptools
=======================

.. automodule:: drain_swamp.backend_setuptools
   :members:
   :undoc-members:
   :exclude-members: PYPROJECT_TOML_SECTION_NAME, BACKEND_NAME
   :platform: Unix
   :synopsis: setuptools backend support
